@@ -17,11 +17,15 @@
 
 from requests.auth import HTTPBasicAuth
 
-from ara.clients.http import AraHttpClient
-from ara.clients.offline import AraOfflineClient
 
-
-def get_client(client="offline", endpoint="http://127.0.0.1:8000", timeout=30, username=None, password=None):
+def get_client(
+    client="offline",
+    endpoint="http://127.0.0.1:8000",
+    timeout=30,
+    username=None,
+    password=None,
+    run_sql_migrations=True,
+):
     """
     Returns a specified client configuration or one with sane defaults.
     """
@@ -30,8 +34,19 @@ def get_client(client="offline", endpoint="http://127.0.0.1:8000", timeout=30, u
         auth = HTTPBasicAuth(username, password)
 
     if client == "offline":
-        return AraOfflineClient(auth=auth)
+        from ara.clients.offline import AraOfflineClient
+
+        return AraOfflineClient(auth=auth, run_sql_migrations=run_sql_migrations)
     elif client == "http":
+        from ara.clients.http import AraHttpClient
+
         return AraHttpClient(endpoint=endpoint, timeout=timeout, auth=auth)
     else:
         raise ValueError(f"Unsupported API client: {client} (use 'http' or 'offline')")
+
+
+def active_client():
+    return active_client._instance()
+
+
+active_client._instance = None
