@@ -1,17 +1,20 @@
 # -*- coding: utf-8 -*-
-#   Copyright 2017 Red Hat, Inc. All Rights Reserved.
+#  Copyright (c) 2018 Red Hat, Inc.
 #
-#   Licensed under the Apache License, Version 2.0 (the "License"); you may
-#   not use this file except in compliance with the License. You may obtain
-#   a copy of the License at
+#  This file is part of ARA Records Ansible.
 #
-#       http://www.apache.org/licenses/LICENSE-2.0
+#  ARA is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#   Unless required by applicable law or agreed to in writing, software
-#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#   License for the specific language governing permissions and limitations
-#   under the License.
+#  ARA is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
 import sys
@@ -20,13 +23,17 @@ import pbr.version
 version_info = pbr.version.VersionInfo('ara')
 
 sys.path.insert(0, os.path.abspath('../..'))
+sys.path.append(os.path.abspath('_extensions'))
 # -- General configuration ----------------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx.ext.autosectionlabel',
+    'pygments_lexer'
 ]
+autosectionlabel_prefix_document = True
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
@@ -40,8 +47,8 @@ master_doc = 'index'
 
 # General information about the project.
 project = u'ara'
-copyright = u'2017, Red Hat'
-author = 'RDO Community'
+copyright = u'2018, Red Hat'
+author = 'OpenStack community'
 
 # The short X.Y version.
 version = version_info.version_string()
@@ -56,7 +63,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'default'
 
 # -- Options for HTML output --------------------------------------------------
 
